{% extends 'base.html' %}

{% block page_header %}
	<h1>Forgotten password</h1>
{% endblock page_header %}

{% block form_content %}
	<p>
		Please check your inbox for an email with instructions on resetting your {{ SITE.name }} password.
	</p>
{% endblock form_content %}