{% extends 'base.html' %}

{% block page_header %}
	<h1>Forgotten password</h1>
{% endblock page_header %}

{% block form_content %}
	<form method="post" class="form-horizontal">
		{% include 'signup/form.inc.html' %}
		
		<div class="Form-actions">
			<button type="submit" class="btn btn-primary">Reset password</button>
		</div>
		
		{% csrf_token %}
	</form>
{% endblock form_content %}